#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hinotify
version:              0.4.2
visibility:           public
id:                   hinotify-0.4.2-AuQpJabKM0jLyVD28LoYQ0
key:                  hinotify-0.4.2-AuQpJabKM0jLyVD28LoYQ0
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Lennart Kolmodin
homepage:             https://github.com/kolmodin/hinotify
synopsis:             Haskell binding to inotify
description:
    This library provides a wrapper to the Linux Kernel'\''s inotify feature,
    allowing applications to subscribe to notifications when a file is
    accessed or modified.

category:             System
abi:                  11a4d12bf3a73f8ff2fdb0dab0692b2c
exposed:              True
exposed-modules:      System.INotify
hidden-modules:       System.INotify.Masks
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hinotify-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hinotify-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hinotify-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hinotify
hs-libraries:         HShinotify-0.4.2-AuQpJabKM0jLyVD28LoYQ0
includes:             sys/inotify.h
depends:
    async-2.2.6-6oBfo7va0Nh7ISraaAL0Gg base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-hinotify/html/hinotify.haddock
haddock-html:         /usr/share/doc/haskell-hinotify/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

